/////////////////////////////////////////////////////////////
//                                                         //
// Copyright (c) 2007-2013 by The University of Queensland //
// Earth Systems Science Computational Centre (ESSCC)      //
// http://www.uq.edu.au/esscc                              //
//                                                         //
// Primary Business: Brisbane, Queensland, Australia       //
// Licensed under the Open Software License version 3.0    //
// http://www.opensource.org/licenses/osl-3.0.php          //
//                                                         //
/////////////////////////////////////////////////////////////

#include <boost/version.hpp>
#include "ClippedCircleVolPy.h"

using namespace boost::python;

    void exportClippedCircleVol()
    {
      // Check that Boost 1.34.0 or higher is being used.
      // If so, disable auto-generation of C++ signatures for Epydoc
      // (which stumbles over indentation in the auto-generated strings).
      #if ((BOOST_VERSION / 100000 >= 1) \
          && (BOOST_VERSION / 100 % 1000 >= 34)) \
          || (BOOST_VERSION / 100000 >= 2)
        boost::python::docstring_options no_autogen(true,false);
      #endif

      class_<ClippedCircleVol, bases<AVolume2D> >(
        "ClippedCircleVol",
        "A class defining a circular volume in 2D clipped by lines.",
        init<>()
      )
      .def(init<const ClippedCircleVol &>())
      .def(
        init<Vector3,double>(
          ( arg("centre"), arg("radius") ),
          "Constructs a circle with the specified centre and radius.\n"
          "@type centre: L{Vector3}\n"
          "@kwarg centre: Coordinates of the centre of the circle\n"
          "@type radius: double\n"
          "@kwarg radius: Radius of the circle\n"
        )
      )
      .def(
        "addLine",
        &ClippedCircleVol::addLine,
        ( arg("line"), arg("fit") ),
        "Adds a line to the volume for clipping the circle.\n"
        "@type line: L{Line2D}\n"
        "@kwarg line: the line to add to the volume\n"
        "@rtype: void\n"
      )
      .def(self_ns::str(self))
      ;
    }
